# tnreason

A package for reasoning using Markov Logic Networks based on Tensor Network algorithms.

Demonstrations can be found here: [Tutorials](https://drive.google.com/drive/folders/1CpeWP2TTFKjjcvwDgxOrq-baZ7nyCpI1?usp=share_link)
